Coverage report

File | class | statements | missing | excluded | coverage
--- | --- | --- | --- | --- | ---
/var/devmt/py/dbilib_0.5.0/dbilib/__init__.py | (no class) | 1 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_base.py | ExitCode | 0 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_base.py | SecurityWarning | 0 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_base.py | _DBIBase | 33 | 0 | 24 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_base.py | (no class) | 30 | 0 | 1 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_mysql.py | _DBIMySQL | 48 | 0 | 12 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_mysql.py | (no class) | 16 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_sqlite.py | _DBISQLite | 10 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_dbi_sqlite.py | (no class) | 10 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/_version.py | (no class) | 1 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.5.0/dbilib/database.py | DBInterface | 19 | 4 | 5 | 79%
/var/devmt/py/dbilib_0.5.0/dbilib/database.py | (no class) | 10 | 0 | 0 | 100%
Total |  | 178 | 4 | 42 | 98%

No items found using the specified filter.